@@ -8,6 +8,10 @@ that organism.
 __author__ = "Brian Connelly <bdc@msu.edu>"
 __credits__ = "Brian Connelly"
 
+import random
+
+from seeds.SEEDSError import *
+
 
 class Cell(object):
     """
@@ -20,8 +24,10 @@ class Cell(object):
     population
         A reference to the Population in which the Cell exists
     id
-        A unique ID representing that Cell.  This should be the same as the
-        node id in the population topology graph.
+        A unique ID representing that Cell
+    node
+        The ID of the node of the population topology graph on which this Cell
+        resides
     types
         List of strings describing the possible types the Cell could be
     type
@@ -49,7 +55,11 @@ class Cell(object):
 
     """
 
-    def __init__(self, experiment, population, id, name=None, label=None):
+    types = []
+    type_colors = []
+    max_types = 0
+
+    def __init__(self, experiment, population, node, type=None, name=None, label=None):
         """Initialize a Cell object
 
         Parameters:
@@ -58,8 +68,11 @@ class Cell(object):
             A reference to the Experiment in which this Cell exists
         *population*
             A reference to the Population in which this Cell exists
-        *id*
-            A unique ID for this cell
+        *node*
+            The ID of the node of the population topology graph on which this
+            Cell resides
+        *type*
+            The type of Cell this is (specific to the Cell class used)
         *name*
             The name of the Cell type
         *label*
@@ -69,13 +82,20 @@ class Cell(object):
 
         self.experiment = experiment
         self.population = population
-        self.id = id
+        self.id = self.population.get_cell_id()
+        self.node = node
         self.name = name
         self.label = label
-        self.type = None
-        self.max_types = 0
         self.type_colors = ['r','g','b','y','c', 'm', 'k']
 
+        if type:
+            if type not in range(len(self.types)):
+                raise CellTypeError(type)
+            else:
+                self.type = type
+        else:
+            self.type = random.randint(0, len(self.types))
+
         if self.label:
             self.config_section = "%s:%s" % (self.name, self.label)
         else:
@@ -103,7 +123,7 @@ class Cell(object):
 
     def get_neighbors(self):
         """Get a list of neighboring cells"""
-        return [self.population.topology.graph.node[n]['cell'] for n in self.population.topology.get_neighbors(self.id)]
+        return self.population.get_neighbors(self)
 
     def update_neighbors(self):
         """Update the list of neighboring cells"""
@@ -119,7 +139,7 @@ class Cell(object):
 
     def coords(self):
         """Get the coordinates of the Cell in space"""
-        return self.population.topology.graph.node[self.id]['coords']
+        return self.population.topology.graph.node[self.node]['coords']
 
     def get_neighbor_distance(self, neighbor):
         """Get the Cartesian distance to the given neighbor Cell"""
